==> zio-aws-ec2_2.13-5.17.127.2-sources.jar: zio/aws/ec2/model/DescribeStoreImageTasksResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeStoreImageTasksResponse(
    storeImageTaskResults: Option[
      Iterable[zio.aws.ec2.model.StoreImageTaskResult]
    ] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse = {
    import DescribeStoreImageTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
      .builder()
      .optionallyWith(
        storeImageTaskResults.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.storeImageTaskResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly =
    zio.aws.ec2.model.DescribeStoreImageTasksResponse.wrap(buildAwsValue())
}
object DescribeStoreImageTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeStoreImageTasksResponse =
      zio.aws.ec2.model.DescribeStoreImageTasksResponse(
        storeImageTaskResults.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def storeImageTaskResults
        : Option[List[zio.aws.ec2.model.StoreImageTaskResult.ReadOnly]]
    def nextToken: Option[String]
    def getStoreImageTaskResults: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.StoreImageTaskResult.ReadOnly
    ]] =
      AwsError.unwrapOptionField("storeImageTaskResults", storeImageTaskResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ) extends zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly {
    override val storeImageTaskResults
        : Option[List[zio.aws.ec2.model.StoreImageTaskResult.ReadOnly]] = scala
      .Option(impl.storeImageTaskResults())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.StoreImageTaskResult.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ): zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.163.1-sources.jar: zio/aws/ec2/model/DescribeStoreImageTasksResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeStoreImageTasksResponse(
    storeImageTaskResults: Optional[
      Iterable[zio.aws.ec2.model.StoreImageTaskResult]
    ] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse = {
    import DescribeStoreImageTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
      .builder()
      .optionallyWith(
        storeImageTaskResults.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.storeImageTaskResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly =
    zio.aws.ec2.model.DescribeStoreImageTasksResponse.wrap(buildAwsValue())
}
object DescribeStoreImageTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeStoreImageTasksResponse =
      zio.aws.ec2.model.DescribeStoreImageTasksResponse(
        storeImageTaskResults.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def storeImageTaskResults
        : Optional[List[zio.aws.ec2.model.StoreImageTaskResult.ReadOnly]]
    def nextToken: Optional[String]
    def getStoreImageTaskResults: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.StoreImageTaskResult.ReadOnly
    ]] =
      AwsError.unwrapOptionField("storeImageTaskResults", storeImageTaskResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ) extends zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly {
    override val storeImageTaskResults
        : Optional[List[zio.aws.ec2.model.StoreImageTaskResult.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.storeImageTaskResults())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.StoreImageTaskResult.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeStoreImageTasksResponse
  ): zio.aws.ec2.model.DescribeStoreImageTasksResponse.ReadOnly = new Wrapper(
    impl
  )
}
